Plugin-Oriented Programming Capabilities
========================================

This document is intended to exhaustively list the functional current and future capabilities of Subpop, with examples
if possible, along with their status.
